@@ -1,7 +1,7 @@
 #!/bin/bash
 # make sure that mkfs.btrfs --rootsize does not change size of the image
 
-source $TOP/tests/common
+source "$TEST_TOP/common"
 
 check_prereq mkfs.btrfs
 
@@ -13,12 +13,10 @@ test_mkfs_with_size() {
 	local tmp
 
 	size="$1"
-	run_check truncate -s$size $TEST_DEV
-	imgsize=$(run_check_stdout stat --format=%s $TEST_DEV)
-	run_check $SUDO_HELPER $TOP/mkfs.btrfs -f \
-		--rootdir $TOP/Documentation \
-		$TEST_DEV
-	tmp=$(run_check_stdout stat --format=%s $TEST_DEV)
+	run_check truncate -s"$size" "$TEST_DEV"
+	imgsize=$(run_check_stdout stat --format=%s "$TEST_DEV")
+	run_check_mkfs_test_dev --rootdir "$INTERNAL_BIN/Documentation"
+	tmp=$(run_check_stdout stat --format=%s "$TEST_DEV")
 	if ! [ "$imgsize" = "$tmp" ]; then
 		_fail "image size changed from $imgsize to $tmp"
 	fi
